==> p5-Alien-wxWidgets-0.47p0.tgz: libdata/perl5/site_perl/mips64el-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include ',
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc',
          'version' => '2.008012',
          'alien_base' => 'gtk2_gcc',
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib -pthread',
          'c_flags' => '-pthread ',
          '_libraries' => {
                            'base' => {
                                        'link' => '-lwx_base',
                                        'dll' => 'libwx_base.so.2.1'
                                      },
                            'richtext' => {
                                            'link' => '-lwx_gtk2_richtext',
                                            'dll' => 'libwx_gtk2_richtext.so.2.1'
                                          },
                            'core' => {
                                        'link' => '-lwx_gtk2_core',
                                        'dll' => 'libwx_gtk2_core.so.2.1'
                                      },
                            'stc' => {
                                       'link' => '-lwx_gtk2_stc',
                                       'dll' => 'libwx_gtk2_stc.so.2.1'
                                     },
                            'fl' => {
                                      'link' => '-lwx_gtk2_fl',
                                      'dll' => 'libwx_gtk2_fl.so.2.1'
                                    },
                            'aui' => {
                                       'link' => '-lwx_gtk2_aui',
                                       'dll' => 'libwx_gtk2_aui.so.2.1'
                                     },
                            'gl' => {
                                      'link' => '-lwx_gtk2_gl',
                                      'dll' => 'libwx_gtk2_gl.so.2.1'
                                    },
                            'net' => {
                                       'link' => '-lwx_base_net',
                                       'dll' => 'libwx_base_net.so.2.1'
                                     },
                            'html' => {
                                        'link' => '-lwx_gtk2_html',
                                        'dll' => 'libwx_gtk2_html.so.2.1'
                                      },
                            'gizmos' => {
                                          'link' => '-lwx_gtk2_gizmos',
                                          'dll' => 'libwx_gtk2_gizmos.so.2.1'
                                        },
                            'qa' => {
                                      'link' => '-lwx_gtk2_qa',
                                      'dll' => 'libwx_gtk2_qa.so.2.1'
                                    },
                            'xml' => {
                                       'link' => '-lwx_base_xml',
                                       'dll' => 'libwx_base_xml.so.2.1'
                                     },
                            'xrc' => {
                                       'link' => '-lwx_gtk2_xrc',
                                       'dll' => 'libwx_gtk2_xrc.so.2.1'
                                     },
                            'adv' => {
                                       'link' => '-lwx_gtk2_adv',
                                       'dll' => 'libwx_gtk2_adv.so.2.1'
                                     }
                          },
          'compiler' => 'c++',
          'link_flags' => '',
          'linker' => 'c++ -shared -fPIC  ',
          'config' => {
                        'compiler_version' => '3.4',
                        'compiler_kind' => 'gcc',
                        'mslu' => 0,
                        'toolkit' => 'gtk2',
                        'unicode' => 0,
                        'debug' => 0,
                        'build' => 'multi'
                      },
          'prefix' => '/usr/local'
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;

==> p5-Alien-wxWidgets-0.62.tgz: libdata/perl5/site_perl/mips64el-openbsd/Alien/wxWidgets/Config/gtk2_gcc.pm <==
package Alien::wxWidgets::Config::gtk2_gcc;

use strict;

our %VALUES;

{
    no strict 'vars';
    %VALUES = %{
$VAR1 = {
          'version' => '2.008012',
          '_libraries' => {
                            'gl' => {
                                      'link' => '-lwx_gtk2_gl',
                                      'dll' => 'libwx_gtk2_gl.so.3.0'
                                    },
                            'fl' => {
                                      'link' => '-lwx_gtk2_fl',
                                      'dll' => 'libwx_gtk2_fl.so.3.0'
                                    },
                            'base' => {
                                        'dll' => 'libwx_base.so.3.0',
                                        'link' => '-lwx_base'
                                      },
                            'core' => {
                                        'link' => '-lwx_gtk2_core',
                                        'dll' => 'libwx_gtk2_core.so.3.0'
                                      },
                            'adv' => {
                                       'dll' => 'libwx_gtk2_adv.so.3.0',
                                       'link' => '-lwx_gtk2_adv'
                                     },
                            'html' => {
                                        'link' => '-lwx_gtk2_html',
                                        'dll' => 'libwx_gtk2_html.so.3.0'
                                      },
                            'net' => {
                                       'dll' => 'libwx_base_net.so.3.0',
                                       'link' => '-lwx_base_net'
                                     },
                            'qa' => {
                                      'dll' => 'libwx_gtk2_qa.so.3.0',
                                      'link' => '-lwx_gtk2_qa'
                                    },
                            'xrc' => {
                                       'link' => '-lwx_gtk2_xrc',
                                       'dll' => 'libwx_gtk2_xrc.so.3.0'
                                     },
                            'xml' => {
                                       'link' => '-lwx_base_xml',
                                       'dll' => 'libwx_base_xml.so.3.0'
                                     },
                            'gizmos' => {
                                          'dll' => 'libwx_gtk2_gizmos.so.3.0',
                                          'link' => '-lwx_gtk2_gizmos'
                                        },
                            'richtext' => {
                                            'dll' => 'libwx_gtk2_richtext.so.3.0',
                                            'link' => '-lwx_gtk2_richtext'
                                          },
                            'aui' => {
                                       'link' => '-lwx_gtk2_aui',
                                       'dll' => 'libwx_gtk2_aui.so.3.0'
                                     },
                            'stc' => {
                                       'link' => '-lwx_gtk2_stc',
                                       'dll' => 'libwx_gtk2_stc.so.3.0'
                                     }
                          },
          'alien_base' => 'gtk2_gcc',
          'link_flags' => '',
          'link_libraries' => ' -L/usr/local/lib -pthread -L/usr/local/lib -L/usr/X11R6/lib',
          'c_flags' => '-pthread ',
          'defines' => '-D_FILE_OFFSET_BITS=64 -D_LARGE_FILES -D_IODBC_ -D__WXGTK__ ',
          'linker' => 'c++ -shared -fPIC  ',
          'include_path' => '-I/usr/local/lib/wx/include/gtk2-unicode-release-2.8 -I/usr/local/include ',
          'prefix' => '/usr/local',
          'compiler' => 'c++',
          'config' => {
                        'mslu' => 0,
                        'unicode' => 0,
                        'compiler_version' => '3.4',
                        'compiler_kind' => 'gcc',
                        'toolkit' => 'gtk2',
                        'debug' => 0,
                        'build' => 'multi'
                      },
          'alien_package' => 'Alien::wxWidgets::Config::gtk2_gcc'
        };
    };
}

my $key = substr __PACKAGE__, 1 + rindex __PACKAGE__, ':';

sub values { %VALUES, key => $key }

sub config {
   +{ %{$VALUES{config}},
      package       => __PACKAGE__,
      key           => $key,
      version       => $VALUES{version},
      }
}

1;
